@@ -1,9 +1,11 @@
-#!/bin/sh
+#!/usr/bin/env sh
+
+STAGING_FOLDER=/mnt/cms-prepack/installer
+mkdir -p $STAGING_FOLDER/templates-par
+cp -p /opt/tandbergtv/cms/workflow/templates/* $STAGING_FOLDER/templates-par/
 
 mkdir -p /mnt/cms-prepack/installer/components/$DEVICE_PATH/rpmfiles/opt/tandbergtv/cms
-mkdir -p /mnt/cms-prepack/installer/templates-par
 mkdir -p /mnt/cms-prepack/installer/deploy-files
 cp -p /opt/cms-prepack/deploy-files/* /mnt/cms-prepack/installer/deploy-files/
-cp -p /opt/tandbergtv/cms/workflow/templates/* /mnt/cms-prepack/installer/templates-par/
 cp -pr /opt/tandbergtv/* /mnt/cms-prepack/installer/components/$DEVICE_PATH/rpmfiles/opt/tandbergtv/
-cp -pr /opt/cms-prepack/resources/* /mnt/cms-prepack/installer/components/$DEVICE_PATH/
\ No newline at end of file
+cp -pr /opt/cms-prepack/resources/* /mnt/cms-prepack/installer/components/$DEVICE_PATH/
